;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'jde-project '("jde-class" "jde-compile" "jde-complete" "jde-db" "jde-help" "jde-imenu" "jde-import" "jde-java-font-lock" "jde-jdb" "jde-open-source" "jde-parse" "jde-run" "jde"))
(custom-add-loads 'widgets '("tree-widget"))
(custom-add-loads 'jde-gen '("jde-gen"))
(custom-add-loads 'jde-ejb '("jde-ejb"))
(custom-add-loads 'jde-java-font-lock-faces '("jde-java-font-lock"))
(custom-add-loads 'jde-db-options '("jde-db"))
(custom-add-loads 'jde-bug '("jde-bug" "jde-dbs"))
(custom-add-loads 'tools '("beanshell" "jde"))
(custom-add-loads 'jde-ant '("jde-ant"))
(custom-add-loads 'jde '("jde-ant" "jde-bug" "jde-checkstyle" "jde-compile" "jde-complete" "jde-db" "jde-ejb" "jde-gen" "jde-javadoc" "jde-make" "jde-package" "jde-plugins" "jde-run" "jde-which-method" "jde-wiz" "jde-xref" "jde"))
(custom-add-loads 'jde-bug-window '("jde-bug"))
(custom-add-loads 'bsh '("beanshell"))
(custom-add-loads 'jde-compile-options '("jde-compile"))
(custom-add-loads 'jde-run-options '("jde-run"))
(custom-add-loads 'jde-checkstyle '("jde-checkstyle"))
(custom-add-loads 'tree-widget '("tree-widget"))
(custom-add-loads 'jde-xref '("jde-xref"))
(custom-add-loads 'jde-package '("jde-package"))
(custom-add-loads 'jde-complete '("jde-complete"))
(custom-add-loads 'jde-wiz '("jde-wiz"))
(custom-add-loads 'jde-which-method '("jde-which-method"))
(custom-add-loads 'font-lock-faces '("jde-java-font-lock"))
(custom-add-loads 'jde-make '("jde-make"))
(custom-add-loads 'jde-javadoc '("jde-javadoc-gen" "jde-javadoc"))

;;; custom-load.el ends here
